<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+95"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+79"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+157"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+152"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+81"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Középpont</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+164"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+154"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+156"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+117"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+121"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+97"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+84"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+90"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+88"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+78"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+108"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+78"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+90"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+82"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+78"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-5"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-5"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Felezőpont</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translation>Sugár</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translation>Kezdőszög</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translation>Végszög</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translation>Fordított</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translation>Átmérő</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+7"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translation>Hossz</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Teljes hossz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translatorcomment>A megrajzolt ív hossza</translatorcomment>
        <translation>Ívszög</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+3"/>
        <source>Area</source>
        <translation>Terület</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Total Area</source>
        <translation>Teljes terület</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+95"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+101"/>
        <source>Tag</source>
        <translatorcomment>The ID of a block attribute, for example &quot;author_name&quot;.</translatorcomment>
        <translation>Címke</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translatorcomment>The label of a block attribute, what the user sees, for example &quot;Author name&quot;</translatorcomment>
        <translation>Kérdés</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <source>Circumference</source>
        <translatorcomment>Kör kerülete</translatorcomment>
        <translation>Kerület</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translation>Méretvonal</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translation>1. méretsegédvonal pont</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translation>2. méretsegédvonal pont</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translatorcomment>Szög méretvonalának darabja</translatorcomment>
        <translation>1. vonal eleje</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translation>1. vonal vége</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translation>2. vonal eleje</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translation>2. vonal vége</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translation>Méretvonal íve</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translation>Húr pont</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translation>Távoli húr pont</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-11"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Origó</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translation>Ordináta</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translatorcomment>Ennek a pontnak írja ki az ordináta &quot;méretvonal&quot; az egyik koordinátájtát (abszcisszát(X) vagy ordinátát(Y))</translatorcomment>
        <translation>Meghatározó pont</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translation>Mutató vonal végpontja</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+172"/>
        <source>Dimension Angle</source>
        <translation>Méretvonal szöge</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-8"/>
        <source>Label</source>
        <translation>Címke</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translation>Tűréshatár</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translation>Felső határ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translation>Alsó határ</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translatorcomment>An important point of a dimension, can be at different locations depending on the dimension type hence probably the vague name.</translatorcomment>
        <translation>Definíciós pont</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Szöveg pozíció</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Text Rotation</source>
        <translation>Szöveg forgatás</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Flip First Arrow</source>
        <translation>Első nyíl megfordítása</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation>Második nyíl megfordítása</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Fixed Extension Line</source>
        <translation>Rögzített méretsegédvonal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension Line Length</source>
        <translation>Méretsegédvonal hossza</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Auto Label</source>
        <translation>Automatikus címke</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Measured Value</source>
        <translation>Mért érték</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Block Name</source>
        <translation>Blokk neve</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Automatikus címke pozíció</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translation>Főtengely pontja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translation>Arány</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translation>Kezdőparaméter</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translation>Végparaméter</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-12"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translation>Kezdőpont</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+4"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translation>Végpont</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-10"/>
        <source>Solid</source>
        <translation>Teljes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Winding</source>
        <translatorcomment>A fill mode in which double-filled areas are also filled, not empty.</translatorcomment>
        <translation>Tekercselés</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alpha</source>
        <translation>Áttetszőség</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Mintázat</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>Elemből</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+14"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-13"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translation>Szög</translation>
    </message>
    <message>
        <location line="+209"/>
        <source>Yes</source>
        <translation>Igen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>Nem</translation>
    </message>
    <message>
        <location line="-208"/>
        <source>Scale</source>
        <translation>Lépték</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translation>Csúcs</translation>
    </message>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="-18"/>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Pozíció</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>U</source>
        <translatorcomment>A vector indicting the direction of the image bottom side (commonly called U vector).</translatorcomment>
        <translation>U</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>V</source>
        <translatorcomment>A vector indicting the direction of the image left side (commonly called V vector).</translatorcomment>
        <translation>V</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translation>Szélesség szorzó</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translation>Magassági szorzó</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width</source>
        <translation>Szélesség</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height</source>
        <translation>Magasság</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Halványítás</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-5"/>
        <source>Arrow</source>
        <translation>Nyíl</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Spline</source>
        <translation>Spline</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Nyíl blokk</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-9"/>
        <source>Polyline Pattern</source>
        <translation>Vonallánc minta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translation>Zárt</translation>
    </message>
    <message>
        <location line="+4"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+0"/>
        <source>Bulge</source>
        <translation>Kidudorodás</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start Width</source>
        <translation>Kezdőszélesség</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Végszélesség</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Globális szélesség</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Irány</translation>
    </message>
    <message>
        <location line="+9"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="-2"/>
        <source>Base Angle</source>
        <translation>Alapszög</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <source>Size 1</source>
        <translation>1. méret</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <source>Size 2</source>
        <translation>2. méret</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Z</source>
        <translation>Globális Z</translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>1. pont</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>2. pont</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translation>3. pont</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translation>4. pont</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
        <source>Closed Periodic</source>
        <translatorcomment>Spline esetén a körbezártság</translatorcomment>
        <translation>Zárt periodikus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Fokozat</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translation>Vezérpont</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translation>Illesztési pont</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Csomó vektor</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Csomó</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use Start Tangent</source>
        <translation>Kezdőérintő használata</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation>Kezdőérintő</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation>Végérintő használata</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation>Végérintő</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Bázispont</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Második pont</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Irányvektor</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Fix szög</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="-3"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+1"/>
        <source>Invisible</source>
        <translation>Láthatatlan</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+190"/>
        <source>Arc Symbol Type</source>
        <translation>Ív szimbólum típusa</translation>
    </message>
    <message>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-5"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction</source>
        <translation>Irány</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <location filename="../src/entity/RLineEntity.cpp" line="-7"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Middle Point</source>
        <translation>Felezőpont</translation>
    </message>
    <message>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+2"/>
        <source>Frame</source>
        <translation>Keret</translation>
    </message>
</context>
</TS>
